from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Sensor_Distance = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'TMF8820', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMF8820'}), 'ref_prefix':'U', 'fplist':['Sensor_Distance:AMS_OLGA12'], 'footprint':'Sensor_Distance:AMS_OLGA12', 'keywords':'TMF882x ToF', 'description':'', 'datasheet':'https://ams.com/documents/20143/6015057/TMF882X_DS000693_8-00.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Distance.kicad_sym\nTMF8820\n\nTMF882x ToF', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GPIO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='INT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VL53L1CXV0FY1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VL53L1CXV0FY1'}), 'ref_prefix':'U', 'fplist':['Sensor_Distance:ST_VL53L1x'], 'footprint':'Sensor_Distance:ST_VL53L1x', 'keywords':'VL53L1x ToF', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/vl53l1x.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Distance.kicad_sym\nVL53L1CXV0FY1\n\nVL53L1x ToF', 'pins':[
            Pin(num='1',name='AVDDVCSEL',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AVSSVCSEL',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='XSHUT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GPIO1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMF8821', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMF8821'}), 'ref_prefix':'U', 'fplist':['Sensor_Distance:AMS_OLGA12', 'Sensor_Distance:AMS_OLGA12'], 'footprint':'Sensor_Distance:AMS_OLGA12', 'keywords':'TMF882x ToF', 'description':'', 'datasheet':'https://ams.com/documents/20143/6015057/TMF882X_DS000693_8-00.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Distance.kicad_sym\nTMF8821\n\nTMF882x ToF', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GPIO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='INT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TMF8828', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TMF8828'}), 'ref_prefix':'U', 'fplist':['Sensor_Distance:AMS_OLGA12', 'Sensor_Distance:AMS_OLGA12', 'Sensor_Distance:AMS_OLGA12'], 'footprint':'Sensor_Distance:AMS_OLGA12', 'keywords':'TMF882x ToF', 'description':'', 'datasheet':'https://ams.com/documents/20143/6015057/TMF882X_DS000693_8-00.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Distance.kicad_sym\nTMF8828\n\nTMF882x ToF', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GPIO1',func=pin_types.TRISTATE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GPIO0',func=pin_types.TRISTATE,unit=1),
            Pin(num='4',name='INT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='5',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='EN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'VL53L0CXV0DH1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'VL53L0CXV0DH1'}), 'ref_prefix':'U', 'fplist':['Sensor_Distance:ST_VL53L1x', 'Sensor_Distance:ST_VL53L1x'], 'footprint':'Sensor_Distance:ST_VL53L1x', 'keywords':'VL53L0x ToF', 'description':'', 'datasheet':'https://www.st.com/resource/en/datasheet/vl53l0x.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Distance.kicad_sym\nVL53L0CXV0DH1\n\nVL53L0x ToF', 'pins':[
            Pin(num='1',name='AVDDVCSEL',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='AVSSVCSEL',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='XSHUT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GPIO1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='8',name='DNC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


# -*- coding: utf-8 -*-

# The MIT License (MIT) - Copyright (c) Dave Vandenbout.

"""
An interface from SKiDL to PySpice.
"""

# Create a SKiDL library of SPICE elements. All PySpice-related info goes into
# a pyspice dictionary that is added as an attribute to the SKiDL Part object.


from skidl import SKIDL, TEMPLATE, Part, Pin, SchLib
from skidl.pin import pin_types
from skidl.tools.spice import (
    add_part_to_circuit,
    add_xspice_to_circuit,
    not_implemented,
)

# Pin aliases.
_POS_DIPOLE_ALIASES = ["+", "plus", "anode", "A"]
_NEG_DIPOLE_ALIASES = ["-", "minus", "m", "negative", "neg", "cathode", "C", "K"]
_POS_IN_PORT_ALIASES = ["+i", "i+", "input_plus", "plus_input"]
_NEG_IN_PORT_ALIASES = ["-i", "i-", "input_minus", "minus_input"]
_POS_OUT_PORT_ALIASES = ["+o", "o+", "output_plus", "plus_output"]
_NEG_OUT_PORT_ALIASES = ["-o", "o-", "output_minus", "minus_output"]

pyspice_lib = SchLib(tool=SKIDL).add_parts(
    *[
        Part(
            name="A",
            aliases=["xspice", "XSPICE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="XSPICE",
            description="XSPICE code module",
            ref_prefix="A",
            pyspice={
                "name": "A",
                "kw": {"model": "model"},
                "add": add_xspice_to_circuit,  # Adding XSPICE part is different than a normal part.
            },
            num_units=1,
            do_erc=True,
            pins=[],
        ),
        Part(
            name="B",
            aliases=["behavsrc", "BEHAVSRC", "behavioralsource", "BEHAVIORALSOURCE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="Behavioral source",
            description="Behavioral (arbitrary) source",
            ref_prefix="B",
            pyspice={
                "name": "B",
                "kw": {
                    "i": "current_expression",
                    "current_expression": "current_expression",
                    "v": "voltage_expression",
                    "voltage_expression": "voltage_expression",
                    "tc1": "tc1",
                    "tc2": "tc2",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="C",
            aliases=["cap", "CAP"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="cap capacitor",
            description="Capacitor",
            ref_prefix="C",
            pyspice={
                "name": "C",
                "kw": {
                    "value": "capacitance",
                    "capacitance": "capacitance",
                    "model": "model",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "scale": "scale",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="BEHAVCAP",
            aliases=["behavcap", "behavioralcap", "BEHAVIORALCAP"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="behavioral capacitor",
            description="Behavioral capacitor",
            ref_prefix="C",
            pyspice={
                "name": "BehavioralCapacitor",
                "kw": {
                    "expression": "expression",
                    "tc1": "tc1",
                    "tc2": "tc2",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="SEMICAP",
            aliases=["semicap", "semiconductorcap", "SEMICONDUCTORCAP"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="semiconductor capacitor",
            description="Semiconductor capacitor",
            ref_prefix="C",
            pyspice={
                "name": "SemiconductorCapacitor",
                "kw": {
                    "value": "capacitance",
                    "model": "model",
                    "length": "length",
                    "l": "length",
                    "width": "width",
                    "w": "width",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "scale": "scale",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="D",
            aliases=["diode", "DIODE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="diode rectifier",
            description="Diode",
            ref_prefix="D",
            pyspice={
                "name": "D",
                "kw": {
                    "model": "model",
                    "area": "area",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "pj": "pj",
                    "off": "off",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="E",
            aliases=["VCVS", "vcvs"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="voltage-controlled voltage source",
            description="Voltage-controlled voltage source",
            ref_prefix="E",
            pyspice={
                "name": "VCVS",
                "kw": {
                    "gain": "voltage_gain",
                    "voltage_gain": "voltage_gain",
                    "op": "output_plus",
                    "on": "output_minus",
                    "ip": "input_plus",
                    "in": "input_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="ip",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_IN_PORT_ALIASES,
                ),
                Pin(
                    num="2",
                    name="in",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_IN_PORT_ALIASES,
                ),
                Pin(
                    num="3",
                    name="op",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_OUT_PORT_ALIASES,
                ),
                Pin(
                    num="4",
                    name="on",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_OUT_PORT_ALIASES,
                ),
            ],
        ),
        Part(
            name="NONLINV",
            aliases=["nonlinv", "nonlinearvoltagesource", "NONLINEARVOLTAGESOURCE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="non-linear voltage source",
            description="Nonlinear voltage source",
            ref_prefix="E",
            pyspice={
                "name": "NonLinearVoltageSource",
                "kw": {
                    "expression": "expression",
                    "table": "table",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="F",
            aliases=["CCCS", "cccs"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="current-controlled current source",
            description="Current-controlled current source",
            ref_prefix="F",
            pyspice={
                "name": "CCCS",
                "kw": {
                    "control": "source",
                    "source": "source",
                    "gain": "current_gain",
                    "current_gain": "current_gain",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="G",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="voltage-controlled current source",
            description="Voltage-controlled current source",
            ref_prefix="G",
            pyspice={
                "name": "VCCS",
                "kw": {
                    "gain": "transconductance",
                    "current_gain": "transconductance",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "op": "output_plus",
                    "on": "output_minus",
                    "ip": "input_plus",
                    "in": "input_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="ip",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_IN_PORT_ALIASES,
                ),
                Pin(
                    num="2",
                    name="in",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_IN_PORT_ALIASES,
                ),
                Pin(
                    num="3",
                    name="op",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_OUT_PORT_ALIASES,
                ),
                Pin(
                    num="4",
                    name="on",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_OUT_PORT_ALIASES,
                ),
            ],
        ),
        Part(
            name="NONLINI",
            aliases=["nonlinvi", "nonlinearcurrentsource", "NONLINEARCURRENTSOURCE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="non-linear current source",
            description="Nonlinear current source",
            ref_prefix="G",
            pyspice={
                "name": "NonLinearCurrentSource",
                "kw": {
                    "expression": "expression",
                    "table": "table",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="H",
            aliases=["CCVS", "ccvs"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="current-controlled voltage source",
            description="Current-controlled voltage source",
            ref_prefix="H",
            pyspice={
                "name": "H",
                "kw": {
                    "control": "source",
                    "source": "source",
                    "transresistance": "transresistance",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="I",
            aliases=["i", "cs", "CS"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="current source",
            description="Current source",
            ref_prefix="I",
            pyspice={
                "name": "I",
                "kw": {
                    "value": "dc_value",
                    "dc_value": "dc_value",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="J",
            aliases=["JFET", "jfet"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="junction field-effect transistor JFET",
            description="Junction field-effect transistor",
            ref_prefix="J",
            pyspice={
                "name": "J",
                "kw": {
                    "model": "model",
                    "area": "area",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "off": "off",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "d": "drain",
                    "g": "gate",
                    "s": "source",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="d",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["drain"],
                ),
                Pin(
                    num="2",
                    name="g",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["gate"],
                ),
                Pin(
                    num="3",
                    name="s",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["source"],
                ),
            ],
        ),
        Part(
            name="K",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="coupled mutual inductors",
            description="Coupled (mutual) inductors",
            ref_prefix="K",
            pyspice={
                "name": "K",
                "kw": {
                    "ind1": "inductor1",
                    "ind2": "inductor2",
                    "coupling": "coupling_factor",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            coupled_parts=[],
            pins=[],
        ),
        Part(
            name="L",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="inductor choke coil reactor magnetic",
            description="Inductor",
            ref_prefix="L",
            pyspice={
                "name": "L",
                "kw": {
                    "value": "inductance",
                    "inductance": "inductance",
                    "model": "model",
                    "nt": "nt",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "scale": "scale",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="BEHAVIND",
            aliases=["behavind", "behavioralind", "BEHAVIORALIND"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="behavioral inductor",
            description="Behavioral inductor",
            ref_prefix="C",
            pyspice={
                "name": "BehavioralInductor",
                "kw": {
                    "expression": "expression",
                    "tc1": "tc1",
                    "tc2": "tc2",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="M",
            aliases=["MOSFET", "mosfet", "FET", "fet"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="metal-oxide field-effect transistor MOSFET",
            description="Metal-oxide field-effect transistor",
            ref_prefix="M",
            pyspice={
                "name": "M",
                "kw": {
                    "model": "model",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "l": "length",
                    "length": "length",
                    "w": "width",
                    "width": "width",
                    "drain_area": "drain_area",
                    "source_area": "source_area",
                    "drain_perimeter": "drain_perimeter",
                    "source_perimeter": "source_perimeter",
                    "drain_number_square": "drain_number_square",
                    "source_number_square": "source_number_square",
                    "off": "off",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "d": "drain",
                    "g": "gate",
                    "s": "source",
                    "b": "bulk",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="d",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["drain"],
                ),
                Pin(
                    num="2",
                    name="g",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["gate"],
                ),
                Pin(
                    num="3",
                    name="s",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["source"],
                ),
                Pin(
                    num="4",
                    name="b",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["bulk", "substrate"],
                ),
            ],
        ),
        Part(  #####################################################################
            name="N",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="numerical device GSS",
            description="Numerical device for GSS",
            ref_prefix="N",
            pyspice={"name": "N", "add": not_implemented},
            num_units=1,
            do_erc=True,
            pins=[],
        ),
        Part(
            name="O",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="lossy transmission line",
            description="Lossy transmission line",
            ref_prefix="O",
            pyspice={
                "name": "O",
                "kw": {
                    "model": "model",
                    "op": "output_plus",
                    "on": "output_minus",
                    "ip": "input_plus",
                    "in": "input_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="ip",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_IN_PORT_ALIASES,
                ),
                Pin(
                    num="2",
                    name="in",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_IN_PORT_ALIASES,
                ),
                Pin(
                    num="3",
                    name="op",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_OUT_PORT_ALIASES,
                ),
                Pin(
                    num="4",
                    name="on",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_OUT_PORT_ALIASES,
                ),
            ],
        ),
        Part(
            name="P",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="coupled multiconductor line",
            description="Coupled multiconductor line",
            ref_prefix="P",
            pyspice={
                "name": "P",
                "kw": {
                    "model": "model",
                    "length": "length",
                    "l": "length",
                    "op": "output_plus",
                    "on": "output_minus",
                    "ip": "input_plus",
                    "in": "input_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[],
        ),  #############################################################
        Part(
            name="Q",
            aliases=("BJT", "bjt"),
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="bipolar transistor npn pnp",
            description="Bipolar Junction Transistor",
            ref_prefix="Q",
            pyspice={
                "name": "Q",
                "kw": {
                    "model": "model",
                    "area": "area",
                    "areab": "areab",
                    "areac": "areac",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "off": "off",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "c": "collector",
                    "b": "base",
                    "e": "emitter",
                    "s": "substrate",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="c",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["collector"],
                ),
                Pin(
                    num="2",
                    name="b",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["base"],
                ),
                Pin(
                    num="3",
                    name="e",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["emitter"],
                ),
                Pin(
                    num="4",
                    name="s",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["substrate", "bulk"],
                ),
            ],
        ),
        Part(
            name="R",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="res resistor",
            description="Resistor",
            ref_prefix="R",
            pyspice={
                "name": "R",
                "kw": {
                    "value": "resistance",
                    "resistance": "resistance",
                    "ac": "ac",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "scale": "scale",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "noisy": "noisy",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="BEHAVRES",
            aliases=["behavres", "behavioralresistor", "BEHAVIORALRESISTOR"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="behavioral resistor",
            description="Behavioral resistor",
            ref_prefix="R",
            pyspice={
                "name": "BehavioralResistor",
                "kw": {
                    "expression": "expression",
                    "tc1": "tc1",
                    "tc2": "tc2",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="SEMIRES",
            aliases=["semires", "semiconductorresistor", "SEMICONDUCTORRESISTOR"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="semiconductor resistor",
            description="Semiconductor resistor",
            ref_prefix="R",
            pyspice={
                "name": "SemiconductorResistor",
                "kw": {
                    "value": "capacitance",
                    "capacitance": "capacitance",
                    "model": "model",
                    "ac": "ac",
                    "length": "length",
                    "l": "length",
                    "width": "width",
                    "w": "width",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "scale": "scale",
                    "temp": "temperature",
                    "temperature": "temperature",
                    "dtemp": "device_temperature",
                    "device_temperature": "device_temperature",
                    "noisy": "noisy",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="S",
            aliases=["VCS", "vcs"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="voltage-controlled switch",
            description="Voltage-controlled switch",
            ref_prefix="S",
            pyspice={
                "name": "S",
                "kw": {
                    "model": "model",
                    "initial_state": "initial_state",
                    "op": "output_plus",
                    "on": "output_minus",
                    "ip": "input_plus",
                    "in": "input_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="ip",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_IN_PORT_ALIASES,
                ),
                Pin(
                    num="2",
                    name="in",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_IN_PORT_ALIASES,
                ),
                Pin(
                    num="3",
                    name="op",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_OUT_PORT_ALIASES,
                ),
                Pin(
                    num="4",
                    name="on",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_OUT_PORT_ALIASES,
                ),
            ],
        ),
        Part(
            name="T",
            aliases=["transmissionline", "TRANSMISSIONLINE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="transmission line",
            description="Transmission line",
            ref_prefix="T",
            pyspice={
                "name": "TransmissionLine",
                "add": add_part_to_circuit,
                "kw": {
                    "impedance": "impedance",
                    "Z0": "impedance",
                    "time_delay": "time_delay",
                    "TD": "time_delay",
                    "frequency": "frequency",
                    "F": "frequency",
                    "normalized_length": "normalized_length",
                    "NL": "normalized_length",
                    "op": "output_plus",
                    "on": "output_minus",
                    "ip": "input_plus",
                    "in": "input_minus",
                },
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="ip",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_IN_PORT_ALIASES,
                ),
                Pin(
                    num="2",
                    name="in",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_IN_PORT_ALIASES,
                ),
                Pin(
                    num="3",
                    name="op",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_OUT_PORT_ALIASES,
                ),
                Pin(
                    num="4",
                    name="on",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_OUT_PORT_ALIASES,
                ),
            ],
        ),
        Part(
            name="U",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="uniformly-distributed RC line",
            description="Uniformly-distributed RC line",
            ref_prefix="U",
            pyspice={
                "name": "U",
                "kw": {
                    "model": "model",
                    "length": "length",
                    "l": "length",
                    "number_of_lumps": "number_of_lumps",
                    "m": "number_of_lumps",
                    "o": "output",
                    "i": "input",
                    "cn": "capacitance_node",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="o",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["output"],
                ),
                Pin(
                    num="2",
                    name="i",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["input"],
                ),
                Pin(
                    num="3",
                    name="cn",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["cap_node", "capacitance_node"],
                ),
            ],
        ),
        Part(
            name="V",
            aliases=["v", "VS", "vs", "AMMETER", "ammeter"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="voltage source",
            description="Voltage source",
            ref_prefix="V",
            pyspice={
                "name": "V",
                "kw": {
                    "value": "dc_value",
                    "dc_value": "dc_value",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="W",
            aliases=["CCS", "ccs"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="current-controlled switch",
            description="Current-controlled switch",
            ref_prefix="W",
            pyspice={
                "name": "W",
                "kw": {
                    "control": "source",
                    "source": "source",
                    "model": "model",
                    "initial_state": "initial_state",
                    "p": "plus",
                    "n": "minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        # Part( #####################################################################
        # name='X',
        # dest=TEMPLATE,
        # tool=SKIDL,
        # keywords='subcircuit',
        # description='Subcircuit',
        # ref_prefix='Y',
        # pyspice={
        # 'name': 'SubCircuitElement',
        # 'add': _add_subcircuit_to_circuit,
        # },
        # num_units=1,
        # do_erc=True,
        # pins=[]),
        Part(
            name="Y",
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="single lossy transmission line",
            description="Single lossy transmission line",
            ref_prefix="Y",
            pyspice={
                "name": "Y",
                "kw": {
                    "model": "model",
                    "length": "length",
                    "l": "length",
                    "op": "output_plus",
                    "on": "output_minus",
                    "ip": "input_plus",
                    "in": "input_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="ip",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_IN_PORT_ALIASES,
                ),
                Pin(
                    num="2",
                    name="in",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_IN_PORT_ALIASES,
                ),
                Pin(
                    num="3",
                    name="op",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_OUT_PORT_ALIASES,
                ),
                Pin(
                    num="4",
                    name="on",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_OUT_PORT_ALIASES,
                ),
            ],
        ),
        Part(
            name="Z",
            aliases=["MESFET", "mesfet"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="metal-semiconductor field-effect transistor MOSFET",
            description="Metal-semiconductor field-effect transistor",
            ref_prefix="Z",
            pyspice={
                "name": "Z",
                "kw": {
                    "model": "model",
                    "area": "area",
                    "multiplier": "multiplier",
                    "m": "multiplier",
                    "off": "off",
                    "ic": "initial_condition",
                    "initial_condition": "initial_condition",
                    "d": "drain",
                    "g": "gate",
                    "s": "source",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="d",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["drain"],
                ),
                Pin(
                    num="2",
                    name="g",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["gate"],
                ),
                Pin(
                    num="3",
                    name="s",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=["source"],
                ),
            ],
        ),
        Part(
            name="SINEV",
            aliases=["sinev", "sinusoidalvoltage", "SINUSOIDALVOLTAGE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="sinusoidal voltage source",
            description="Sinusoidal voltage source",
            ref_prefix="V",
            pyspice={
                "name": "SinusoidalVoltageSource",
                "kw": {
                    "dc_offset": "dc_offset",
                    "ac_magnitude": "ac_magnitude",
                    "ac_phase": "ac_phase",
                    "offset": "offset",
                    "amplitude": "amplitude",
                    "frequency": "frequency",
                    "delay": "delay",
                    "damping_factor": "damping_factor",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="SINEI",
            aliases=["sinei", "sinusoidalcurrent", "SINUSOIDALCURRENT"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="simusoidal current source",
            description="Sinusoidal current source",
            ref_prefix="I",
            pyspice={
                "name": "SinusoidalCurrentSource",
                "kw": {
                    "dc_offset": "dc_offset",
                    "ac_magnitude": "ac_magnitude",
                    "ac_phase": "ac_phase",
                    "offset": "offset",
                    "amplitude": "amplitude",
                    "frequency": "frequency",
                    "delay": "delay",
                    "damping_factor": "damping_factor",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="PULSEV",
            aliases=["pulsev", "pulsevoltage", "PULSEVOLTAGE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="pulsed voltage source",
            description="Pulsed voltage source",
            ref_prefix="V",
            pyspice={
                "name": "PulseVoltageSource",
                "kw": {
                    "initial_value": "initial_value",
                    "pulsed_value": "pulsed_value",
                    "delay_time": "delay_time",
                    "rise_time": "rise_time",
                    "fall_time": "fall_time",
                    "pulse_width": "pulse_width",
                    "period": "period",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="PULSEI",
            aliases=["pulsei", "pulsecurrent", "PULSECURRENT"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="pulsed current source",
            description="Pulsed current source",
            ref_prefix="I",
            pyspice={
                "name": "PulseCurrentSource",
                "kw": {
                    "initial_value": "initial_value",
                    "pulsed_value": "pulsed_value",
                    "delay_time": "delay_time",
                    "rise_time": "rise_time",
                    "fall_time": "fall_time",
                    "pulse_width": "pulse_width",
                    "period": "period",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="EXPV",
            aliases=["expv", "exponentialvoltage", "EXPONENTIALVOLTAGE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="exponential voltage source",
            description="Exponential voltage source",
            ref_prefix="V",
            pyspice={
                "name": "ExponentialVoltageSource",
                "kw": {
                    "initial_value": "initial_value",
                    "pulsed_value": "pulsed_value",
                    "rise_delay_time": "rise_delay_time",
                    "rise_time_constant": "rise_time_constant",
                    "fall_delay_time": "fall_delay_time",
                    "fall_time_constant": "fall_time_constant",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="EXPI",
            aliases=["expi", "exponentialcurrent", "EXPONENTIALCURRENT"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="exponential current source",
            description="Exponential current source",
            ref_prefix="I",
            pyspice={
                "name": "ExponentialCurrentSource",
                "kw": {
                    "initial_value": "initial_value",
                    "pulsed_value": "pulsed_value",
                    "rise_delay_time": "rise_delay_time",
                    "rise_time_constant": "rise_time_constant",
                    "fall_delay_time": "fall_delay_time",
                    "fall_time_constant": "fall_time_constant",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="PWLV",
            aliases=["pwlv", "piecewiselinearvoltage", "PIECEWISELINEARVOLTAGE"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="piecewise linear voltage source",
            description="Piecewise linear voltage source",
            ref_prefix="V",
            pyspice={
                "name": "PieceWiseLinearVoltageSource",
                "kw": {
                    "values": "values",
                    "repeate_time": "repeate_time",
                    "delay_time": "delay_time",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="PWLI",
            aliases=["pwli", "piecewiselinearcurrent", "PIECEWISELINEARCURRENT"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="piecewise linear current source",
            description="Piecewise linear current source",
            ref_prefix="I",
            pyspice={
                "name": "PieceWiseLinearCurrentSource",
                "kw": {
                    "values": "values",
                    "repeate_time": "repeate_time",
                    "delay_time": "delay_time",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="FMV",
            aliases=[
                "fmv",
                "SFFMV",
                "sffmv",
                "SINGLEFREQUENCYFMVOLTAGE",
                "singlefrequencyfmvoltage",
            ],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="single frequency FM modulated voltage source",
            description="Single-frequency FM-modulated voltage source",
            ref_prefix="V",
            pyspice={
                "name": "SingleFrequencyFMVoltageSource",
                "kw": {
                    "offset": "offset",
                    "amplitude": "amplitude",
                    "carrier_frequency": "carrier_frequency",
                    "modulation_index": "modulation_index",
                    "signal_frequency": "signal_frequency",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="FMI",
            aliases=[
                "fmi",
                "SFFMI",
                "sffmi",
                "SINGLEFREQUENCYFMCURRENT",
                "singlefrequencyfmcurrent",
            ],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="single frequency FM modulated current source",
            description="Single-frequency FM-modulated current source",
            ref_prefix="I",
            pyspice={
                "name": "SingleFrequencyFMCurrentSource",
                "kw": {
                    "offset": "offset",
                    "amplitude": "amplitude",
                    "carrier_frequency": "carrier_frequency",
                    "modulation_index": "modulation_index",
                    "signal_frequency": "signal_frequency",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="AMV",
            aliases=["amv", "AMPLITUDEMODULATEDVOLTAGE", "amplitudemodulatedvoltage"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="amplitude modulated voltage source",
            description="Amplitude-modulated voltage source",
            ref_prefix="V",
            pyspice={
                "name": "AmplitudeModulatedVoltageSource",
                "kw": {
                    "offset": "offset",
                    "amplitude": "amplitude",
                    "carrier_frequency": "carrier_frequency",
                    "modulating_frequency": "modulating_frequency",
                    "signal_delay": "signal_delay",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="AMI",
            aliases=["ami", "AMPLITUDEMODULATEDCURRENT", "amplitudemodulatedcurrent"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="amplitude modulated current source",
            description="Amplitude-modulated current source",
            ref_prefix="I",
            pyspice={
                "name": "AmplitudeModulatedCurrentSource",
                "kw": {
                    "offset": "offset",
                    "amplitude": "amplitude",
                    "carrier_frequency": "carrier_frequency",
                    "modulating_frequency": "modulating_frequency",
                    "signal_delay": "signal_delay",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="RNDV",
            aliases=["rndv", "RANDOMVOLTAGE", "randomvoltage"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="random voltage source",
            description="Random voltage source",
            ref_prefix="V",
            pyspice={
                "name": "RandomVoltageSource",
                "kw": {
                    "random_type": "random_type",
                    "duration": "duration",
                    "time_delay": "time_delay",
                    "parameter1": "parameter1",
                    "parameter2": "parameter2",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
        Part(
            name="RNDI",
            aliases=["rndi", "RANDOMCURRENT", "randomcurrent"],
            dest=TEMPLATE,
            tool=SKIDL,
            keywords="random current source",
            description="Random current source",
            ref_prefix="I",
            pyspice={
                "name": "RandomCurrentSource",
                "kw": {
                    "random_type": "random_type",
                    "duration": "duration",
                    "time_delay": "time_delay",
                    "parameter1": "parameter1",
                    "parameter2": "parameter2",
                    "p": "node_plus",
                    "n": "node_minus",
                },
                "add": add_part_to_circuit,
            },
            num_units=1,
            do_erc=True,
            pins=[
                Pin(
                    num="1",
                    name="p",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_POS_DIPOLE_ALIASES,
                ),
                Pin(
                    num="2",
                    name="n",
                    func=pin_types.PASSIVE,
                    do_erc=True,
                    aliases=_NEG_DIPOLE_ALIASES,
                ),
            ],
        ),
    ]
)



from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_GPS = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'L70-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L70-R'}), 'ref_prefix':'U', 'fplist':['RF_GPS:Quectel_L70-R'], 'footprint':'RF_GPS:Quectel_L70-R', 'keywords':'quectel GPS GNSS module', 'description':'', 'datasheet':'https://www.quectel.com/product/gps-only-l70-r', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nL70-R\n\nquectel GPS GNSS module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='ANTON',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TXD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='1PPS',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='STANDBY',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'L80-R', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'L80-R'}), 'ref_prefix':'U', 'fplist':['RF_GPS:Quectel_L80-R'], 'footprint':'RF_GPS:Quectel_L80-R', 'keywords':'quectel GPS GNSS module', 'description':'', 'datasheet':'https://www.quectel.com/UploadImage/Downlad/Quectel_L80-R_Hardware_Design_V1.2.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nL80-R\n\nquectel GPS GNSS module', 'pins':[
            Pin(num='1',name='RXD1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='TXD1',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='1PPS',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='RESERVED',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LEA-M8F', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LEA-M8F'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_LEA'], 'footprint':'RF_GPS:ublox_LEA', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/products/documents/LEA-M8F_DataSheet_%28UBX-14001772%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nLEA-M8F\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='SDA2/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='V_ANT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCL2/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='FREQ_PHASE_IN1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='SDA_DAC',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='SCL_DAC',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='FREQ_PHASE_IN0',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='TIMEPULSE/TP2/~{SAFEBOOT}',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='TxD1/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RxD1/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='REF_FREQ_OUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LEA-M8S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LEA-M8S'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_LEA'], 'footprint':'RF_GPS:ublox_LEA', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/LEA-M8S-FW3_DataSheet_%28UBX-16010205%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nLEA-M8S\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='V_ANT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='EXTINT1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='EXTINT0',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='RESERVED',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LEA-M8T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LEA-M8T'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_LEA'], 'footprint':'RF_GPS:ublox_LEA', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/documents/NEO-LEA-M8T-FW3_DataSheet_UBX-15025193.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nLEA-M8T\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='TP2/~{SAFEBOOT}',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='19',name='V_ANT',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='EXTINT1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='EXTINT0',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='9',name='RESERVED',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX-8C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX-8C'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_MAX'], 'footprint':'RF_GPS:ublox_MAX', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/MAX-8_DataSheet_%28UBX-16000093%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nMAX-8C\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX-M10S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX-M10S'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_MAX'], 'footprint':'RF_GPS:ublox_MAX', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/MAX-M10S_DataSheet_UBX-20035208.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nMAX-M10S\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='VIO_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX-M8W', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX-M8W'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_MAX'], 'footprint':'RF_GPS:ublox_MAX', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/MAX-M8-FW3_DataSheet_%28UBX-15031506%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nMAX-M8W\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='V_ANT',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NEO-M8M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NEO-M8M'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_NEO'], 'footprint':'RF_GPS:ublox_NEO', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/NEO-M8-FW3_DataSheet_UBX-15031086.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nNEO-M8M\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC_RF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NEO-M8N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NEO-M8N'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_NEO'], 'footprint':'RF_GPS:ublox_NEO', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/NEO-M8-FW3_DataSheet_UBX-15031086.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nNEO-M8N\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC_RF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NEO-M8P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NEO-M8P'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_NEO'], 'footprint':'RF_GPS:ublox_NEO', 'keywords':'ublox GPS GNSS RTK module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/NEO-M8P_DataSheet_UBX-15016656.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nNEO-M8P\n\nublox GPS GNSS RTK module', 'pins':[
            Pin(num='1',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RTK_STAT',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='GEOFENCE_STAT',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC_RF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NEO-M8T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NEO-M8T'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_NEO'], 'footprint':'RF_GPS:ublox_NEO', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/documents/NEO-LEA-M8T-FW3_DataSheet_UBX-15025193.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nNEO-M8T\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='TP2/~{SAFEBOOT}',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='EXTINT1',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXTINT0',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC_RF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RXM-GPS-RM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RXM-GPS-RM'}), 'ref_prefix':'U', 'fplist':['RF_GPS:Linx_RXM-GPS'], 'footprint':'RF_GPS:Linx_RXM-GPS', 'keywords':'gps low-power', 'description':'', 'datasheet':'https://linxtechnologies.com/wp/wp-content/uploads/rxm-gps-rm.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nRXM-GPS-RM\n\ngps low-power', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='VBCKUP',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RFIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1PPS',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SAM-M8Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SAM-M8Q'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_SAM-M8Q'], 'footprint':'RF_GPS:ublox_SAM-M8Q', 'keywords':'gps module with antenna', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/SAM-M8Q_DataSheet_%28UBX-16012619%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nSAM-M8Q\n\ngps module with antenna', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='SDA',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SIM28ML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SIM28ML'}), 'ref_prefix':'U', 'fplist':['RF_GPS:SIM28ML'], 'footprint':'RF_GPS:SIM28ML', 'keywords':'GPS A-GPS receiver', 'description':'', 'datasheet':'https://simcom.ee/documents/SIM28ML/SIM28ML_Hardware%20Design_V1.01.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nSIM28ML\n\nGPS A-GPS receiver', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='ANTON',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='Vcc_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='TXD1/SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RXD1/SCL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='TXD0',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD0',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TIMEMARK',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BACKUP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='Vcc',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZED-F9P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZED-F9P'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_ZED'], 'footprint':'RF_GPS:ublox_ZED', 'keywords':'u-blox GNSS multi-band RTK', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/ZED-F9P-04B_DataSheet_UBX-21044850.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nZED-F9P\n\nu-blox GNSS multi-band RTK', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='GEOFENCE_STAT',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='RTK_STAT',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='24',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='RXD2',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='TXD2',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='35',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='V_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='39',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='ANT_DETECT',func=pin_types.INPUT,unit=1),
            Pin(num='40',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='43',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='SCL/SPI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='TX_READY',func=pin_types.OUTPUT,unit=1),
            Pin(num='47',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='48',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='49',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='ANT_OFF',func=pin_types.OUTPUT,unit=1),
            Pin(num='50',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='53',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='54',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='55',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~{ANT_SHORT}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='Reserved',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZOE-M8G', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZOE-M8G'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_ZOE_M8'], 'footprint':'RF_GPS:ublox_ZOE_M8', 'keywords':'ublox gnss sip', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/ZOE-M8_HIM_UBX-16030136.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nZOE-M8G\n\nublox gnss sip', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='SQI_D1',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='C4',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='C6',name='PIO15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='SQI_D0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='~{SQI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SQI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='SQI_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F1',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F3',name='SQI_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F6',name='PIO14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PIO13/EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='G5',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='H9',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='J5',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='RTC_I',func=pin_types.INPUT,unit=1),
            Pin(num='J8',name='RTC_O',func=pin_types.OUTPUT,unit=1),
            Pin(num='J9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'ZOE-M8Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ZOE-M8Q'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_ZOE_M8'], 'footprint':'RF_GPS:ublox_ZOE_M8', 'keywords':'ublox gnss sip', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/ZOE-M8_HIM_UBX-16030136.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nZOE-M8Q\n\nublox gnss sip', 'pins':[
            Pin(num='A1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='A3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A4',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='A5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A6',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='A7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A8',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='A9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B1',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='B9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C1',name='SQI_D1',func=pin_types.INPUT,unit=1),
            Pin(num='C3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='C4',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='C5',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='C6',name='PIO15',func=pin_types.BIDIR,unit=1),
            Pin(num='C7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D1',name='SQI_D0',func=pin_types.BIDIR,unit=1),
            Pin(num='D3',name='~{SQI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='D4',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='D6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D9',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E1',name='SQI_CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='E3',name='SQI_D2',func=pin_types.BIDIR,unit=1),
            Pin(num='E7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E9',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F1',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F3',name='SQI_D3',func=pin_types.BIDIR,unit=1),
            Pin(num='F4',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='F6',name='PIO14',func=pin_types.BIDIR,unit=1),
            Pin(num='F7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='F9',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G1',name='V_CORE',func=pin_types.PWRIN,unit=1),
            Pin(num='G3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G4',name='PIO13/EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='G5',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='G6',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G7',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='G9',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='H1',name='V_DCDC_OUT',func=pin_types.PWROUT,unit=1),
            Pin(num='H9',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='J1',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='J2',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='J3',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='J4',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='J5',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='J6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='J7',name='RTC_I',func=pin_types.INPUT,unit=1),
            Pin(num='J8',name='RTC_O',func=pin_types.OUTPUT,unit=1),
            Pin(num='J9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX-8Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX-8Q'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_MAX', 'RF_GPS:ublox_MAX'], 'footprint':'RF_GPS:ublox_MAX', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/MAX-8_DataSheet_%28UBX-16000093%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nMAX-8Q\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX-M8C', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX-M8C'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_MAX', 'RF_GPS:ublox_MAX', 'RF_GPS:ublox_MAX'], 'footprint':'RF_GPS:ublox_MAX', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/MAX-M8-FW3_DataSheet_%28UBX-15031506%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nMAX-M8C\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX-M8Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX-M8Q'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_MAX', 'RF_GPS:ublox_MAX', 'RF_GPS:ublox_MAX', 'RF_GPS:ublox_MAX'], 'footprint':'RF_GPS:ublox_MAX', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/MAX-M8-FW3_DataSheet_%28UBX-15031506%29.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nMAX-M8Q\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='VCC_RF',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='Reserved',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TXD',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='RXD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCC_IO',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='~{RESET}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NEO-8Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NEO-8Q'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_NEO', 'RF_GPS:ublox_NEO'], 'footprint':'RF_GPS:ublox_NEO', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/documents/NEO-8Q_DataSheet_UBX-15031913.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nNEO-8Q\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC_RF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NEO-M8Q', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NEO-M8Q'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_NEO', 'RF_GPS:ublox_NEO', 'RF_GPS:ublox_NEO'], 'footprint':'RF_GPS:ublox_NEO', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://content.u-blox.com/sites/default/files/NEO-M8-FW3_DataSheet_UBX-15031086.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nNEO-M8Q\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC_RF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'NEO-M9N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'NEO-M9N'}), 'ref_prefix':'U', 'fplist':['RF_GPS:ublox_NEO', 'RF_GPS:ublox_NEO', 'RF_GPS:ublox_NEO', 'RF_GPS:ublox_NEO'], 'footprint':'RF_GPS:ublox_NEO', 'keywords':'ublox GPS GNSS module', 'description':'', 'datasheet':'https://www.u-blox.com/sites/default/files/NEO-M9N-00B_DataSheet_UBX-19014285.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nNEO-M9N\n\nublox GPS GNSS module', 'pins':[
            Pin(num='1',name='~{SAFEBOOT}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RF_IN',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='LNA_EN',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='RESERVED',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='SDA/~{SPI_CS}',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='SCL/SPI_CLK',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='D_SEL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='TXD/SPI_MISO',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='RXD/SPI_MOSI',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='V_BCKP',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TIMEPULSE',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='EXTINT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='USB_DM',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='USB_DP',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='VDD_USB',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VCC_RF',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'RXM-GPS-FM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'RXM-GPS-FM'}), 'ref_prefix':'U', 'fplist':['RF_GPS:Linx_RXM-GPS', 'RF_GPS:Linx_RXM-GPS'], 'footprint':'RF_GPS:Linx_RXM-GPS', 'keywords':'gps low-power', 'description':'', 'datasheet':'https://linxtechnologies.com/wp/wp-content/uploads/rxm-gps-fm.pdf', 'search_text':'/usr/share/kicad/symbols/RF_GPS.kicad_sym\nRXM-GPS-FM\n\ngps low-power', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='VBCKUP',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='RFIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='1PPS',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='TX',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] })])